@@ -1,3 +1,4 @@
+{-# OPTIONS_GHC -fplugin=LiquidHaskellBoot #-}
 {-# OPTIONS_GHC -Wno-unused-imports #-}
 module Data.String_LHAssumptions where
 
@@ -5,10 +6,10 @@ import Data.String
 import GHC.Types_LHAssumptions()
 
 {-@
-measure stringlen :: a -> GHC.Types.Int
+measure stringlen :: a -> Int
 
-assume Data.String.fromString
-    ::  forall a. Data.String.IsString a
-    =>  i : [GHC.Types.Char]
+assume fromString
+    ::  forall a. IsString a
+    =>  i : [Char]
     ->  { o : a | i ~~ o && len i == stringlen o }
 @-}
