@@ -1,17 +1,19 @@
+{-# OPTIONS_GHC -fplugin=LiquidHaskellBoot #-}
 {-# OPTIONS_GHC -Wno-unused-imports #-}
 module Foreign.ForeignPtr_LHAssumptions where
 
 import Foreign.Concurrent_LHAssumptions()
 import Foreign.ForeignPtr
+import GHC.ForeignPtr
 import GHC.ForeignPtr_LHAssumptions()
 
 {-@
 
-assume GHC.ForeignPtr.withForeignPtr :: forall a b. fp:(GHC.ForeignPtr.ForeignPtr a)
-  -> ((PtrN a (fplen fp)) -> GHC.Types.IO b)
-  -> (GHC.Types.IO b)
+assume withForeignPtr :: forall a b. fp:(ForeignPtr a)
+  -> ((PtrN a (fplen fp)) -> IO b)
+  -> IO b
 
-assume Foreign.ForeignPtr.Imp.newForeignPtr ::  _ -> p:(PtrV a) -> (GHC.Types.IO (ForeignPtrN a (plen p)))
+assume newForeignPtr ::  _ -> p:(PtrV a) -> (IO (ForeignPtrN a (plen p)))
 
 
 //  this uses `sizeOf (undefined :: a)`, so the ForeignPtr does not necessarily have length `n`
